#include <iostream>
#include <map>
#include <vector>
#include <set>
#include <cstdio>

using namespace std;

typedef int weightType;

class Network
{
public:
	Network();
	~Network();
	void init();
	void addNode(const int &new_id, const weightType &new_weight);
	void addArc(const int &new_id1, const int &new_id2, const weightType &new_weight);
	int getNode(const int &nodeID);
	int getArc(const int &nodeID1, const int &nodeID2);
	bool hasNode(const int &nodeID);
	bool hasArc(const int &nodeID1, const int &nodeID2);
	void removeNode(const int &nodeID);
	void removeArc(const int &nodeID1, const int &nodeID2);
	void getP(const vector<int> path);
private:
	map<int, map<int, weightType> > arc;
	map<int, weightType> node;
};

Network::Network()
{
}

Network::~Network()
{
	arc.clear();
	node.clear();
}
void Network::init()
{
	arc.clear();
	node.clear();
}
void Network::addNode(const int &new_id, const weightType &new_weight)
{
	if(node.find(new_id) == node.end())
		node[new_id] = new_weight;
}
void Network::addArc(const int &new_id1, const int &new_id2, const weightType &new_weight)
{
	map<int, map<int, weightType> >::iterator it;
	it = arc.find(new_id1);
	if (it == arc.end())
	{
		arc[new_id1][new_id2] = new_weight;
		return;
	}
	else
	{
		if (it->second.find(new_id2) == it->second.end())
		{
			arc[new_id1][new_id2] = new_weight;
		}
	}
}
int Network::getNode(const int &nodeID)
{
	return node.find(nodeID)->second;
}

int Network::getArc(const int &nodeID1, const int &nodeID2)
{
	return arc[nodeID1][nodeID2];
}
bool Network::hasNode(const int &nodeID)
{
	if(node.find(nodeID) == node.end())
	{
		return false;
	}
	else
	{
		return true;
	}
}

bool Network::hasArc(const int &nodeID1, const int &nodeID2)
{
	map<int, weightType> oldValue;
	if (arc.count(nodeID1) > 0)
	{
		oldValue = arc.find(nodeID1)->second;
		if(oldValue.count(nodeID2) > 0)
		{
			return true;
		}
		else
		{
			return false;
		}		
	}

}
void Network::removeNode(const int &nodeID)
{
	if(node.find(nodeID) != node.end())
		node.erase(node.find(nodeID));
}

void Network::removeArc(const int &nodeID1, const int &nodeID2)
{
	map<int, weightType> oldValue;
	if (hasArc(nodeID1, nodeID2))
	{
		oldValue = arc.find(nodeID1)->second;
		oldValue.erase(nodeID2);
		if (oldValue.empty())
		{
			arc.erase(nodeID1);
		}
		else
		{
			arc[nodeID1] = oldValue;
		}
	}
}
void Network::getP(const vector<int> path)
{
	int sumLength = 0;
	int sumSupply = 0;

	// total_length_of_path 
	bool isEveryArcExist = false;

	for (int i = 0; i < path.size()-1; i++)
	{
		if (hasNode(path[i]) && hasNode(path[i+1]) && hasArc(path[i], path[i+1]) )
		{
			sumLength += getArc(path[i], path[i+1]);
			isEveryArcExist = true;
		}
		else
		{
			isEveryArcExist = false;
			break;
		}
	}	

	if (isEveryArcExist)
	{
		// sum_of_supply_quantities
		set<int> path_set;
		set<int>::iterator it;
		for (int i = 0; i < path.size(); i++)
		{
			path_set.insert(path[i]);
		}	
		for (it=path_set.begin(); it!=path_set.end(); ++it)
		{
    		sumSupply += getNode(*it);
		}
		cout << sumLength << " " << sumSupply << endl;
	}
	else
	{
		cout << "0" << endl;
	}

}
int main()
{
	Network net;
	
	char task[6];
	string pre_task = "P";
	int id1 = 0, id2 = 0, weight = 0;
	char a;
	Network network;

	while (cin >> task)
	{
		if (task[0] == 'A' && task[1] == 'N')
		{
			if (pre_task == "P")
			{
				pre_task = "AN";
				network.init();	
			}
			cin >> id1 >> weight;
			network.addNode(id1, weight);
		}
		else if (task[0] == 'A' && task[1] == 'A')
		{
			// cin >> id1 >> id2 >> weight; // too slow
			scanf("%d %d %d", &id1,&id2,&weight);
			network.addArc(id1, id2, weight);
		}
		else if (task[0] == 'R' && task[1] == 'N')
		{
			cin >> id1;
			network.removeNode(id1);
		}
		else if (task[0] == 'R' && task[1] == 'A')
		{
			cin >> id1 >> id2;
			network.removeArc(id1, id2);
		}
		else if (task[0] == 'P')
		{
			pre_task = "P";
			int length = 0;
			int nodeFrom = 0, nodeTo = 0;
			vector<int> path;


			while(true)
			{
				a = cin.get();
				if(a == '\n')
				{
					break;
				}
				else if (a == ' ')
				{

				}
				else
				{	
					cin.putback(a);
					cin >> id1;
					path.push_back(id1);
				}
			}
			// output result
			network.getP(path);
		}
	}
	return 0;
}